Resiliency.BackoffRetry.Abort (Resiliency v0.6.0)

Copy Markdown View Source

Wraps a reason to signal that retry should stop immediately.

Return {:error, Resiliency.BackoffRetry.abort(reason)} from the retried function to abort without further attempts, regardless of retry_if.

Summary

Types

t()

@type t() :: %Resiliency.BackoffRetry.Abort{reason: any()}